@@ -6,7 +6,6 @@ use AsyncAws\Core\AbstractApi;
 use AsyncAws\Core\AwsError\AwsErrorFactoryInterface;
 use AsyncAws\Core\AwsError\JsonRpcAwsErrorFactory;
 use AsyncAws\Core\Configuration;
-use AsyncAws\Core\Exception\UnsupportedRegion;
 use AsyncAws\Core\RequestContext;
 use AsyncAws\Core\Result;
 use AsyncAws\Sqs\Enum\MessageSystemAttributeName;
@@ -258,7 +257,7 @@ class SqsClient extends AbstractApi
      *
      *   > You can't change the queue type after you create it and you can't convert an existing standard queue into a FIFO
      *   > queue. You must either create a new FIFO queue for your application or delete your existing standard queue and
-     *   > recreate it as a FIFO queue. For more information, see Moving From a Standard Queue to a FIFO Queue [^1] in the
+     *   > recreate it as a FIFO queue. For more information, see Moving From a standard queue to a FIFO queue [^1] in the
      *   > *Amazon SQS Developer Guide*.
      *
      * - If you don't provide a value for an attribute, the queue is created with the default value for the attribute.
@@ -746,7 +745,7 @@ class SqsClient extends AbstractApi
      * ! `#x9` | `#xA` | `#xD` | `#x20` to `#xD7FF` | `#xE000` to `#xFFFD` | `#x10000` to `#x10FFFF`
      * !
      * ! Amazon SQS does not throw an exception or completely reject the message if it contains invalid characters. Instead,
-     * ! it replaces those invalid characters with `U+FFFD` before storing the message in the queue, as long as the message
+     * ! it replaces those invalid characters with U+FFFD before storing the message in the queue, as long as the message
      * ! body contains at least one valid character.
      *
      * [^1]: http://www.w3.org/TR/REC-xml/#charsets
@@ -819,7 +818,7 @@ class SqsClient extends AbstractApi
      * ! `#x9` | `#xA` | `#xD` | `#x20` to `#xD7FF` | `#xE000` to `#xFFFD` | `#x10000` to `#x10FFFF`
      * !
      * ! Amazon SQS does not throw an exception or completely reject the message if it contains invalid characters. Instead,
-     * ! it replaces those invalid characters with `U+FFFD` before storing the message in the queue, as long as the message
+     * ! it replaces those invalid characters with U+FFFD before storing the message in the queue, as long as the message
      * ! body contains at least one valid character.
      *
      * If you don't specify the `DelaySeconds` parameter for an entry, Amazon SQS uses the default value for the queue.
@@ -891,44 +890,6 @@ class SqsClient extends AbstractApi
         }
 
         switch ($region) {
-            case 'af-south-1':
-            case 'ap-east-1':
-            case 'ap-northeast-1':
-            case 'ap-northeast-2':
-            case 'ap-northeast-3':
-            case 'ap-south-1':
-            case 'ap-south-2':
-            case 'ap-southeast-1':
-            case 'ap-southeast-2':
-            case 'ap-southeast-3':
-            case 'ap-southeast-4':
-            case 'ap-southeast-5':
-            case 'ap-southeast-7':
-            case 'ca-central-1':
-            case 'ca-west-1':
-            case 'eu-central-1':
-            case 'eu-central-2':
-            case 'eu-north-1':
-            case 'eu-south-1':
-            case 'eu-south-2':
-            case 'eu-west-1':
-            case 'eu-west-2':
-            case 'eu-west-3':
-            case 'il-central-1':
-            case 'me-central-1':
-            case 'me-south-1':
-            case 'mx-central-1':
-            case 'sa-east-1':
-            case 'us-east-1':
-            case 'us-east-2':
-            case 'us-west-1':
-            case 'us-west-2':
-                return [
-                    'endpoint' => "https://sqs.$region.amazonaws.com",
-                    'signRegion' => $region,
-                    'signService' => 'sqs',
-                    'signVersions' => ['v4'],
-                ];
             case 'cn-north-1':
             case 'cn-northwest-1':
                 return [
@@ -980,7 +941,6 @@ class SqsClient extends AbstractApi
                     'signVersions' => ['v4'],
                 ];
             case 'fips-us-gov-east-1':
-            case 'us-gov-east-1':
                 return [
                     'endpoint' => 'https://sqs.us-gov-east-1.amazonaws.com',
                     'signRegion' => 'us-gov-east-1',
@@ -988,7 +948,6 @@ class SqsClient extends AbstractApi
                     'signVersions' => ['v4'],
                 ];
             case 'fips-us-gov-west-1':
-            case 'us-gov-west-1':
                 return [
                     'endpoint' => 'https://sqs.us-gov-west-1.amazonaws.com',
                     'signRegion' => 'us-gov-west-1',
@@ -1044,7 +1003,12 @@ class SqsClient extends AbstractApi
                 ];
         }
 
-        throw new UnsupportedRegion(\sprintf('The region "%s" is not supported by "Sqs".', $region));
+        return [
+            'endpoint' => "https://sqs.$region.amazonaws.com",
+            'signRegion' => $region,
+            'signService' => 'sqs',
+            'signVersions' => ['v4'],
+        ];
     }
 
     protected function getServiceCode(): string
